@@ -91,7 +91,6 @@ static int
 ProcXTestGetVersion(ClientPtr client)
 {
     xXTestGetVersionReply rep;
-    int n;
 
     REQUEST_SIZE_MATCH(xXTestGetVersionReq);
     rep.type = X_Reply;
@@ -100,8 +99,8 @@ ProcXTestGetVersion(ClientPtr client)
     rep.majorVersion = XTestMajorVersion;
     rep.minorVersion = XTestMinorVersion;
     if (client->swapped) {
-        swaps(&rep.sequenceNumber, n);
-        swaps(&rep.minorVersion, n);
+        swaps(&rep.sequenceNumber);
+        swaps(&rep.minorVersion);
     }
     WriteToClient(client, sizeof(xXTestGetVersionReply), (char *)&rep);
     return Success;
@@ -114,7 +113,7 @@ ProcXTestCompareCursor(ClientPtr client)
     xXTestCompareCursorReply rep;
     WindowPtr pWin;
     CursorPtr pCursor;
-    int n, rc;
+    int rc;
     DeviceIntPtr ptr = PickPointer(client);
 
     REQUEST_SIZE_MATCH(xXTestCompareCursorReq);
@@ -139,7 +138,7 @@ ProcXTestCompareCursor(ClientPtr client)
     rep.sequenceNumber = client->sequence;
     rep.same = (wCursor(pWin) == pCursor);
     if (client->swapped) {
-        swaps(&rep.sequenceNumber, n);
+        swaps(&rep.sequenceNumber);
     }
     WriteToClient(client, sizeof(xXTestCompareCursorReply), (char *)&rep);
     return Success;
@@ -348,7 +347,7 @@ ProcXTestFakeInput(ClientPtr client)
         if (client->swapped)
         {
             (void) XTestSwapFakeInput(client, (xReq *)stuff);
-            swaps(&stuff->length, n);
+            swaps(&stuff->length);
         }
         ResetCurrentRequest (client);
         client->sequence--;
@@ -476,25 +475,23 @@ ProcXTestDispatch (ClientPtr client)
 static int
 SProcXTestGetVersion(ClientPtr client)
 {
-    int n;
     REQUEST(xXTestGetVersionReq);
 
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     REQUEST_SIZE_MATCH(xXTestGetVersionReq);
-    swaps(&stuff->minorVersion, n);
+    swaps(&stuff->minorVersion);
     return ProcXTestGetVersion(client);
 }
 
 static int
 SProcXTestCompareCursor(ClientPtr client)
 {
-    int n;
     REQUEST(xXTestCompareCursorReq);
 
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     REQUEST_SIZE_MATCH(xXTestCompareCursorReq);
-    swapl(&stuff->window, n);
-    swapl(&stuff->cursor, n);
+    swapl(&stuff->window);
+    swapl(&stuff->cursor);
     return ProcXTestCompareCursor(client);
 }
 
@@ -525,10 +522,10 @@ XTestSwapFakeInput(ClientPtr client, xReq *req)
 static int
 SProcXTestFakeInput(ClientPtr client)
 {
-    int n;
+	int n;
     REQUEST(xReq);
 
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     n = XTestSwapFakeInput(client, stuff);
     if (n != Success)
         return n;
@@ -538,10 +535,9 @@ SProcXTestFakeInput(ClientPtr client)
 static int
 SProcXTestGrabControl(ClientPtr client)
 {
-    int n;
     REQUEST(xXTestGrabControlReq);
 
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     REQUEST_SIZE_MATCH(xXTestGrabControlReq);
     return ProcXTestGrabControl(client);
 }
