@@ -78,13 +78,11 @@ SOFTWARE.
 int
 SProcXUngrabDeviceKey(ClientPtr client)
 {
-    char n;
-
     REQUEST(xUngrabDeviceKeyReq);
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     REQUEST_SIZE_MATCH(xUngrabDeviceKeyReq);
-    swapl(&stuff->grabWindow, n);
-    swaps(&stuff->modifiers, n);
+    swapl(&stuff->grabWindow);
+    swaps(&stuff->modifiers);
     return (ProcXUngrabDeviceKey(client));
 }
 
