@@ -133,10 +133,8 @@ void XISendDeviceHierarchyEvent(int flags[MAXDEVICES])
 
 int SProcXIChangeHierarchy(ClientPtr client)
 {
-    char n;
-
     REQUEST(xXIChangeHierarchyReq);
-    swaps(&stuff->length, n);
+    swaps(&stuff->length);
     return (ProcXIChangeHierarchy(client));
 }
 
@@ -202,19 +200,6 @@ unwind:
     return rc;
 }
 
-static void
-disable_clientpointer(DeviceIntPtr dev)
-{
-    int i;
-
-    for (i = 0; i < currentMaxClients; i++)
-    {
-        ClientPtr client = clients[i];
-        if (client && client->clientPtr == dev)
-            client->clientPtr = NULL;
-    }
-}
-
 static int
 remove_master(ClientPtr client, xXIRemoveMasterInfo *r,
               int flags[MAXDEVICES])
@@ -265,8 +250,6 @@ remove_master(ClientPtr client, xXIRemoveMasterInfo *r,
     if (rc != Success)
         goto unwind;
 
-    disable_clientpointer(ptr);
-
     /* Disabling sends the devices floating, reattach them if
      * desired. */
     if (r->return_mode == XIAttachToMaster)
@@ -439,7 +422,6 @@ ProcXIChangeHierarchy(ClientPtr client)
 {
     xXIAnyHierarchyChangeInfo *any;
     int required_len = sizeof(xXIChangeHierarchyReq);
-    char n;
     int rc = Success;
     int flags[MAXDEVICES] = {0};
 
@@ -452,8 +434,8 @@ ProcXIChangeHierarchy(ClientPtr client)
     any = (xXIAnyHierarchyChangeInfo*)&stuff[1];
     while(stuff->num_changes--)
     {
-        SWAPIF(swapl(&any->type, n));
-        SWAPIF(swaps(&any->length, n));
+        SWAPIF(swaps(&any->type));
+        SWAPIF(swaps(&any->length));
 
         required_len += any->length;
         if ((stuff->length * 4) < required_len)
@@ -464,7 +446,7 @@ ProcXIChangeHierarchy(ClientPtr client)
             case XIAddMaster:
                 {
                     xXIAddMasterInfo* c = (xXIAddMasterInfo*)any;
-                    SWAPIF(swaps(&c->name_len, n));
+                    SWAPIF(swaps(&c->name_len));
 
                     rc = add_master(client, c, flags);
                     if (rc != Success)
