@@ -280,9 +280,7 @@ ddxProcessArgument(int argc, char *argv[], int i)
 	int screenNum;
 	CHECK_FOR_REQUIRED_ARGUMENTS(2);
 	screenNum = atoi(argv[i+1]);
-	/* The protocol only has a CARD8 for number of screens in the
-	   connection setup block, so don't allow more than that. */
-	if ((screenNum < 0) || (screenNum >= 255))
+	if (screenNum < 0)
 	{
 	    ErrorF("Invalid screen number %d\n", screenNum);
 	    UseMsg();
@@ -762,8 +760,7 @@ vfbWriteXWDFileHeader(ScreenPtr pScreen)
 	SwapLongs((CARD32 *)pXWDHeader, SIZEOF(XWDheader)/4);
 	for (i = 0; i < pvfb->ncolors; i++)
 	{
-	    register char n;
-	    swapl(&pvfb->pXWDCmap[i].pixel, n);
+	    swapl(&pvfb->pXWDCmap[i].pixel);
 	}
     }
 }
